window.Gleam.initSearch([{"doc":"base_x_gleam","title":"base_x_gleam","content":"# base_x_gleam\nBase-X encoding and decoding implementation in Gleam!\n\nAllows the creation of encoders and decoders for arbitrary character sets (alphabets).\n\nCan be used for encoding and decoding hexadecimal and base-64, but is mostly most useful for more archaic alphabets (like base58 used in some blockchain applications).\n\nCurrently only supports the Erlang target.\n\nAlso see [the Elixir `BaseX` library](https://hexdocs.pm/basex/BaseX.html) and [the Javascript `base-x` npm package](https://www.npmjs.com/package/base-x)\n\n[![Package Version](https://img.shields.io/hexpm/v/base_x_gleam)](https://hex.pm/packages/base_x_gleam)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/base_x_gleam/)\n\n```sh\ngleam add base_x_gleam\n```\n```gleam\nimport base_x_gleam\nimport gleam/bit_array\n\npub fn main() {\n  // base58 alphabet\n  let b58_alphabet = &quot;123456789ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnopqrstuvwxyz&quot;\n  // Will return an error if the alphabet contains duplicates\n  let assert Ok(b58_encoder, b58_decoder) = base_x_gleam.generate(alphabet)\n  &quot;foobar&quot;\n  |&gt; bit_array.from_string\n  |&gt; b58_encoder    // &quot;t1Zv2yaZ&quot;\n\n  &quot;3FhSYN5Ra1ZtmGfAC&quot;\n  |&gt; b58_decoder    // Ok(&lt;&lt;&quot;wibblewobble&quot;&gt;&gt;)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/base_x_gleam&gt;.","url":"index.html"},{"doc":"base_x_gleam","title":"generate","content":"pub fn generate(\n  alphabet alphabet: String,\n) -&gt; Result(\n  #(fn(BitArray) -&gt; String, fn(String) -&gt; Result(BitArray, Nil)),\n  Nil,\n)\n Returns a tuple containing the encoding and decoding functions.\nSynonyms:\nbase_x_gleam.generate\nbase_x_gleam generate","url":"base_x_gleam.html#generate"},{"doc":"base_x_gleam","title":"base_x_gleam","content":"","url":"base_x_gleam.html"}]);